# --- ENV KEYS ---
OPENAI_API_KEY = "OPENAI_API_KEY"
GEMINI_API_KEY = "GEMINI_API_KEY"

# --- INPUT FORMAT KEYS ---
INPUT = "input"
CURRENT = "current"
HISTORY = "history"
ROLE = "role"
QUERY = "query"
RESPONSE = "response"
TIMESTAMP = "timestamp"
ASSISTANT = "assistant"
USER = "user"

# SYSTEM PROMPTS
CLASSIFIER_PROMPT = "intent_classifier.md"
NOTES_CREATOR_PROMPT = "note_creator.md"
QUERY_REPHRASOR_PROMPT = "query_rephraser.md"
